@@ -370,7 +370,7 @@ def trigger_set_value_task(set_value_fields, conf, rule, session_name, vtiger_ac
 
     print("Inside trigger_set_value_task")
     id = conf.get('data').get('id', '')
-    lead_id = conf.get('data').get('lead_id', '')
+    lead_id = conf.get('data').get('leadid', '')
     record_module = 'Leads'
     module = module_id_dict.get(record_module, '')
     print("Id: {}".format(id))
